@@ -156,20 +156,7 @@ void BatchRenamer::processFilenames()
         QString name = executePlugin( i, (*m_files)[i].dstFilename(), ePluginType_Filename, errors, NULL );
         if( !name.isNull() ) 
             (*m_files)[i].setDstFilename( name );
-        
-        (void)applyManualChanges( i );
-        
-        // Assemble filenames
-        //parseSubdirs( &m_files[i] );
-        // TODO: DOM 
-        // ESCAPE HERE
-        /*
-          m_files[i].src.name = BatchRenamer::buildFilename( &m_files[i].src, true );
-          
-          
-          m_files[i].dst.name = BatchRenamer::buildFilename( &m_files[i].dst, true );
-        */
-        
+                
         /*
          * take care of renamed directories and
          * correct the paths of their contents
@@ -246,6 +233,9 @@ void BatchRenamer::processFiles( ProgressDialog* p )
         if( p->wasCancelled() )
             break;
 
+        // Assemble filenames
+        createMissingSubDirs( (*m_files)[i], p );
+        
         KIO::JobFlags flags  = (m_overwrite ? KIO::Overwrite : KIO::DefaultFlags) | KIO::HideProgressInfo;
         KIO::Job*     job    = NULL;
         const KUrl &  srcUrl =  (*m_files)[i].srcUrl();
@@ -303,7 +293,7 @@ void BatchRenamer::processFiles( ProgressDialog* p )
     p->print( i18n("KRename finished the renaming process."), "krename" );
     p->print( i18n("Press close to quit!") );
     bool enableUndo = (m_renameMode != eRenameMode_Copy);
-    p->renamingDone( enableUndo, this, errors );
+    p->renamingDone( true, enableUndo, this, errors );
     
 #if 0
     delete object;
@@ -336,8 +326,6 @@ void BatchRenamer::processFiles( ProgressDialog* p )
         if( !extext.isEmpty() )
             m_files[i].dst.extension = processString( extext, m_files[i].src.extension, i );
 
-        (void)applyManualChanges( i );
-
         // Assemble filenames
         parseSubdirs( &m_files[i] );
         // TODO: DOM 
@@ -425,7 +413,7 @@ void BatchRenamer::undoFiles( ProgressDialog* p )
 
     p->print( i18n("KRename finished the undo process."), "krename" );
     p->print( i18n("Press close to quit!") );
-    p->renamingDone( false, this, errors ); // do not allow undo from undo
+    p->renamingDone( false, false, this, errors ); // do not allow undo from undo
 
 }
 
@@ -446,7 +434,16 @@ QString BatchRenamer::processBrackets( QString text, int* length, const QString
             QString substitute = processBrackets( text.right( text.length() - pos ), &localLength, oldname, index );
             text.replace( pos - 1, localLength, substitute );
             // MSG: qDebug("substituted: %s\n", text.toUtf8().data() );
-            *length += (localLength - substitute.length() );
+            // Assure that *length does not become negative,
+            // this will cause infinite loops
+            if( localLength < substitute.length() ) 
+            {
+                *length += localLength;
+            }
+            else
+            {
+                *length += (localLength - substitute.length() );
+            }
         }
         else if( token == "]" ) 
         {
@@ -578,7 +575,7 @@ QString BatchRenamer::processString( QString text, const QString & originalName,
                     }
                 }
 
-		// -2 because we have to go, before the current found token
+                // -2 because we have to go, before the current found token
                 appendix = text.mid( curPos + 1, appendixPos - curPos - 2 );
                 appendixLength = appendixPos - curPos;
             }
@@ -586,8 +583,8 @@ QString BatchRenamer::processString( QString text, const QString & originalName,
             QString number   = processNumber( count, appendix );
             text.replace( pos - 1, (length + appendixLength), number );
 
-	    if( number.length() > 0 )
-		pos += number.length() - 1;
+            if( number.length() > 0 )
+                pos += number.length() - 1;
         }
     }
 
@@ -945,7 +942,6 @@ QString BatchRenamer::findToken( const QString & oldname, QString token, int i )
             break;
     }
 
-    doEscape( token );
     return token;
 }
 
@@ -1144,58 +1140,31 @@ void BatchRenamer::writeUndoScript( QTextStream* t )
          << "fi" << endl;
 }
 
-#if 0
-void BatchRenamer::parseSubdirs( data* f )
+void BatchRenamer::createMissingSubDirs( const KRenameFile & file, ProgressDialog* p )
 {
     int pos = 0;
-    if( (pos = f->dst.name.findRev( "/", -1 ) ) > 0 ) {
-        QString dirs = f->dst.name.left( pos );
-        f->dst.name = f->dst.name.right( f->dst.name.length() - pos - 1 );
-        f->dst.directory += ( f->dst.directory.right( 1 ) == "/" ) ? "" : "/";
+    QString dstFilename = file.dstFilename();
+    if( (pos = dstFilename.lastIndexOf( '/', -1 ) ) > 0 ) {
+        QString directories = dstFilename.left( pos );
 
         // create the missing subdir now
         int i = 0;
-        QString d = "";
-        while( (d = dirs.section( "/", i, i, QString::SectionSkipEmpty )) && ! d.isEmpty() ) { // asignment here!
-            KURL url = f->dst.url;
+        QString d = directories.section( "/", i, i, QString::SectionSkipEmpty );
+        KUrl url = file.dstUrl();            
+        while( !d.isEmpty() ) {
             // it is important to unescape here
             // to support dirnames containing "&" or 
             // similar tokens
             url.addPath( unEscape( d ) );
-            if( !NetAccess::exists( url ) && !NetAccess::mkdir( url ) )
-                // TODO: GUI bug report
-                qDebug("Can't create %s", url.prettyURL().latin1() ); 
+            if( !KIO::NetAccess::exists( url, true, p ) && !KIO::NetAccess::mkdir( url, p ) ) {
+                p->error( i18n("Cannot create directory %1", url.prettyUrl()) );
+            }
 
-            f->dst.url.addPath( d );
-            f->dst.directory.append( d + "/" );
             i++;
+            d = directories.section( "/", i, i, QString::SectionSkipEmpty );
         }
     }
 }
-#endif // 0
-
-bool BatchRenamer::applyManualChanges( int i )
-{
-    /*
-     * The last step: make changes of
-     * the user visible
-     */
-
-    if( !m_changes.isEmpty() )
-        for( int z = 0; z < m_changes.count(); z++ ) {
-            KUrl file = m_changes[z].url;
-            if( file == (*m_files)[i].srcUrl() ) {
-                (*m_files)[i].setDstFilename( m_changes[z].user );
-
-                // the file extension is already included
-                // in the users name
-                (*m_files)[i].setDstExtension( QString::null );
-                return true;
-            }
-        }
-
-    return false;
-}
 
 void BatchRenamer::findCounterReset( int i )
 {
