@@ -167,7 +167,7 @@ void KRenameImpl::setupSlots()
 
 void KRenameImpl::addFileOrDir( const KUrl & url )
 {
-    KRenameFile       item( url );
+    KRenameFile       item( url, m_lastSplitMode, m_lastDot );
     KRenameFile::List list;
 
     list.append( item );
@@ -184,7 +184,7 @@ void KRenameImpl::addFilesOrDirs( const KUrl::List & list, const QString & filte
     
     while( it != list.end() )
     {
-        KRenameFile item( *it );
+        KRenameFile item( *it, m_lastSplitMode, m_lastDot );
         if( item.isDirectory() )
         {
             KApplication::setOverrideCursor( Qt::BusyCursor );
@@ -557,17 +557,15 @@ void KRenameImpl::slotExtensionSplitModeChanged( ESplitMode splitMode, int dot )
 
     m_lastSplitMode = splitMode;
     m_lastDot       = dot;
+
+    m_model->setExtensionSplitMode( m_lastSplitMode, m_lastDot );
 }
 
 void KRenameImpl::slotStart()
 {
-    ProgressDialog* progress = new ProgressDialog();
+    ProgressDialog* progress = new ProgressDialog( m_lastSplitMode, m_lastDot );
     progress->print( i18n("Starting conversion of %1 files.", m_vector.count()) );
 
-    // Make sure the GUI will not delete our models
-    m_window->setModel( NULL );
-    m_window->setPreviewModel( NULL );
-
     // Get some properties from the gui and initialize BatchRenamer
     const KUrl & destination = m_window->destinationUrl();
     if( m_renamer.renameMode() != eRenameMode_Rename && 
@@ -592,6 +590,10 @@ void KRenameImpl::slotStart()
     // requires access to the window
     saveConfig();
 
+    // Make sure the GUI will not delete our models
+    m_window->setModel( NULL );
+    m_window->setPreviewModel( NULL );
+
     // show the progress dialog
     progress->show();
     progress->raise();
@@ -622,10 +624,10 @@ void KRenameImpl::loadConfig()
     KConfigGroup groupGui = config->group( QString("GUISettings") );
     //groupGui.readEntry( "firststart4", QVariant(true) ).toBool();
     m_window->setPreviewEnabled( 
-	groupGui.readEntry( "ImagePreview", QVariant(false) ).toBool() );
+	groupGui.readEntry( "ImagePreview2", QVariant(true) ).toBool() );
 
     m_window->setPreviewNamesEnabled( 
-	groupGui.readEntry( "ImagePreviewName", QVariant(false) ).toBool() );
+	groupGui.readEntry( "ImagePreviewName2", QVariant(true) ).toBool() );
 
     m_window->setAdvancedMode( 
 	groupGui.readEntry( "Advanced", QVariant(false) ).toBool() );
@@ -640,15 +642,11 @@ void KRenameImpl::loadConfig()
     int sortMode = groupGui.readEntry( "FileListSorting", QVariant(0) ).toInt();
     m_window->setSortMode( sortMode );
 
-    int width = groupGui.readEntry( "Column0", QVariant(m_window->previewColumnWidth( 0 )) ).toInt();
-    if( width > 0 )
-		m_window->setPreviewColumnWidth( 0, width );
-
-    width = groupGui.readEntry( "Column1", QVariant(m_window->previewColumnWidth( 1 )) ).toInt();
-    if( width > 0 )
-	    m_window->setPreviewColumnWidth( 1, width );
-
-
+    ESplitMode lastSplitMode = static_cast<ESplitMode>(groupGui.readEntry( "ExtensionSplitMode", static_cast<int>(m_lastSplitMode) ));
+    int lastDot = groupGui.readEntry( "ExtensionSplitDot", m_lastDot );    
+    m_window->setExtensionSplitMode( lastSplitMode, lastDot );
+    this->slotExtensionSplitModeChanged( lastSplitMode, lastDot );
+    
     // load Plugin configuration
     KConfigGroup groupPlugins = config->group( QString("PluginSettings") );
     m_pluginLoader->loadConfig( groupPlugins );
@@ -670,14 +668,14 @@ void KRenameImpl::saveConfig()
 
     KConfigGroup groupGui = config->group( QString("GUISettings") );
     groupGui.writeEntry( "firststart4", false );
-    groupGui.writeEntry( "ImagePreview", m_window->isPreviewEnabled() );
-    groupGui.writeEntry( "ImagePreviewName", m_window->isPreviewNamesEnabled() );
+    groupGui.writeEntry( "ImagePreview2", m_window->isPreviewEnabled() );
+    groupGui.writeEntry( "ImagePreviewName2", m_window->isPreviewNamesEnabled() );
     groupGui.writeEntry( "StartIndex", m_window->numberStartIndex() );
     groupGui.writeEntry( "Stepping", m_renamer.numberStepping() );
     groupGui.writeEntry( "FileListSorting", m_window->sortMode() );
-    groupGui.writeEntry( "Column0", m_window->previewColumnWidth( 0 ) );
-    groupGui.writeEntry( "Column1", m_window->previewColumnWidth( 1 ) );
     groupGui.writeEntry( "Advanced", m_window->isAdvancedMode() );
+    groupGui.writeEntry( "ExtensionSplitMode", static_cast<int>(m_lastSplitMode) );
+    groupGui.writeEntry( "ExtensionSplitDot", m_lastDot );    
 
     // save Plugin configuration
     KConfigGroup groupPlugins = config->group( QString("PluginSettings") );
